@@ -1,4 +1,3 @@
-# styler: off
 #' Return filtered or sliced data frame, or row indices
 #'
 #' Return a filtered (or sliced) data frame or row indices of a data frame that
@@ -63,6 +62,7 @@
 #' working with labelled data.
 #'
 #' @examples
+#' # styler: off
 #' data_match(mtcars, data.frame(vs = 0, am = 1))
 #' data_match(mtcars, data.frame(vs = 0, am = c(0, 1)))
 #'
@@ -94,6 +94,7 @@
 #'
 #' # string can also be used directly as argument
 #' data_filter(mtcars, "am != 0")
+#' # styler: on
 #' @inherit data_rename seealso
 #' @export
 data_match <- function(x, to, match = "and", return_indices = FALSE, drop_na = TRUE, ...) {
@@ -126,7 +127,7 @@ data_match <- function(x, to, match = "and", return_indices = FALSE, drop_na = T
 
   # prepare
   if (identical(match, "or")) {
-    idx <- c()
+    idx <- vector("numeric", length = 0L)
   } else {
     # remove missings before matching
     if (isTRUE(drop_na)) {
@@ -159,6 +160,8 @@ data_match <- function(x, to, match = "and", return_indices = FALSE, drop_na = T
     out <- idx
   }
 
+  # add back custom attributes
+  out <- .replace_attrs(out, attributes(original_x))
   out
 }
 
@@ -167,8 +170,21 @@ data_match <- function(x, to, match = "and", return_indices = FALSE, drop_na = T
 #' @rdname data_match
 #' @export
 data_filter <- function(x, filter, ...) {
+  UseMethod("data_filter")
+}
+
+#' @export
+data_filter.data.frame <- function(x, filter, ...) {
   condition <- substitute(filter)
 
+  dots <- list(...)
+
+  # if called from data_filter.grouped_df, the substitute above just gets
+  # "filter" whereas it needs to pass the condition
+  if ("called_from_group" %in% names(dots) && dots$called_from_group) {
+    condition <- substitute(filter, env = parent.frame(3L))
+  }
+
   # condition can be a numeric vector, to slice rows by indices,
   # or a logical condition to filter observations. first, we check
   # for numeric vector. the logical condition can also be passed
@@ -190,14 +206,19 @@ data_filter <- function(x, filter, ...) {
     has_curley <- grepl("{", condition, fixed = TRUE)
 
     if (has_curley) {
-      condition <- gsub("\\{ ", "\\{", condition)
-      condition <- gsub(" \\}", "\\}", condition)
+      condition <- gsub("{ ", "{", condition, fixed = TRUE)
+      condition <- gsub(" }", "}", condition, fixed = TRUE)
 
       curley_vars <- regmatches(condition, gregexpr("[^{\\}]+(?=\\})", condition, perl = TRUE))
-      curley_vars <- unlist(curley_vars)
+      curley_vars <- unique(unlist(curley_vars, use.names = FALSE))
 
       for (i in curley_vars) {
-        token <- get(i, envir = parent.frame())
+        if (isTRUE(dots$called_from_group)) {
+          token <- get(i, envir = parent.frame(4L))
+        } else {
+          token <- get(i, envir = parent.frame())
+        }
+
         condition <- gsub(paste0("{", i, "}"), token, condition, fixed = TRUE)
       }
     }
@@ -218,6 +239,29 @@ data_filter <- function(x, filter, ...) {
     attr(out[[i]], "label") <- attr(x[[i]], "label", exact = TRUE)
     attr(out[[i]], "labels") <- attr(x[[i]], "labels", exact = TRUE)
   }
+
+  # add back custom attributes
+  out <- .replace_attrs(out, attributes(x))
+  out
+}
+
+
+#' @export
+data_filter.grouped_df <- function(x, filter, ...) {
+  # works only for dplyr >= 0.8.0
+  grps <- attr(x, "groups", exact = TRUE)
+  grps <- grps[[".rows"]]
+
+  out <- lapply(grps, function(grp) {
+    data_filter.data.frame(x[grp, ], filter, called_from_group = TRUE, ...)
+  })
+
+  out <- do.call(rbind, out)
+
+  if (!insight::object_has_rownames(x)) {
+    rownames(out) <- NULL
+  }
+
   out
 }
 
@@ -261,4 +305,3 @@ data_filter <- function(x, filter, ...) {
     )
   }
 }
-# styler: on
