@@ -172,9 +172,6 @@ data_join <- data_merge
 #' @rdname data_merge
 #' @export
 data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, verbose = TRUE, ...) {
-  # save data frame attributes
-  attr_x <- attributes(x)
-  attr_y <- attributes(y)
   class_x <- class(x)
 
   # save variable attributes
@@ -292,7 +289,7 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
   if (!is.null(out$.data_merge_id_x)) {
     # for full joins, we have no complete sorting id, but NAs for each
     # data frame. we now "merge" the two sorting IDs from each data frame.
-    if (any(is.na(out$.data_merge_id_x)) && !is.null(out$.data_merge_id_y)) {
+    if (anyNA(out$.data_merge_id_x) && !is.null(out$.data_merge_id_y)) {
       out$.data_merge_id_x[is.na(out$.data_merge_id_x)] <- out$.data_merge_id_y[is.na(out$.data_merge_id_x)]
     }
     out <- out[order(out$.data_merge_id_x), ]
@@ -312,8 +309,8 @@ data_merge.data.frame <- function(x, y, join = "left", by = NULL, id = NULL, ver
   out <- out[all_columns]
 
   # add back attributes
-  attributes(out) <- utils::modifyList(attr_y, attributes(out))
-  attributes(out) <- utils::modifyList(attr_x, attributes(out))
+  out <- .replace_attrs(out, attributes(y))
+  out <- .replace_attrs(out, attributes(x))
 
   for (i in colnames(out)) {
     if (is.list(attr_vars[[i]])) {
