@@ -56,9 +56,11 @@ data_partition <- function(data,
   data <- .coerce_to_dataframe(data)
 
   if (sum(proportion) > 1) {
-    insight::format_error("`proportion` cannot be higher than 1.")
+    insight::format_error("Sum of `proportion` cannot be higher than 1.")
+  }
+  if (any(proportion < 0)) {
+    insight::format_error("Values in `proportion` cannot be negative.")
   }
-
   if (sum(proportion) == 1 && isTRUE(verbose)) {
     insight::format_warning(
       "Proportions of sampled training sets (`proportion`) sums up to 1, so no test set will be generated."
@@ -149,7 +151,7 @@ data_partition <- function(data,
   # remove all training set id's from data, add remaining data (= test set)
   out <- c(
     training_sets,
-    list(test = data[-unlist(lapply(training_sets, data_extract, select = row_id, as_data_frame = FALSE)), ])
+    list(test = data[-unlist(lapply(training_sets, data_extract, select = row_id, as_data_frame = FALSE), use.names = FALSE), ])
   )
 
   lapply(out, `row.names<-`, NULL)
