@@ -1,4 +1,3 @@
-
 #' @title Read (import) data files from various sources
 #' @name data_read
 #'
@@ -8,8 +7,8 @@
 #' `readxl::read_excel()` and `data.table::fread()` resp. `readr::read_delim()`
 #' (the latter if package **data.table** is not installed). Thus, supported file
 #' types for importing data are data files from SPSS, SAS or Stata, Excel files
-#' or text files (like '.csv' files). All non-supported file types are passed
-#' to `rio::import()`.
+#' or text files (like '.csv' files). All other file types are passed to
+#' `rio::import()`. `data_write()` works in a similar way.
 #'
 #' @param path Character string, the file path to the data file.
 #' @param path_catalog Character string, path to the catalog file. Only relevant
@@ -19,17 +18,25 @@
 #' values have a value label, are assumed to be categorical and converted
 #' into factors. If `FALSE`, no variable types are guessed and no conversion
 #' of numeric variables into factors will be performed. See also section
-#' 'Differences to other packages'.
+#' 'Differences to other packages'. For `data_write()`, this argument only
+#' applies to the text (e.g. `.txt` or `.csv`) or spreadsheet file formats (like
+#' `.xlsx`). Converting to factors might be useful for these formats because
+#' labelled numeric variables are then converted into factors and exported as
+#' character columns - else, value labels would be lost and only numeric values
+#' are written to the file.
 #' @param verbose Toggle warnings and messages.
-#' @param ... Arguments passed to the related `read_*()` function.
+#' @param ... Arguments passed to the related `read_*()` or `write_*()` functions.
 #'
 #' @return A data frame.
 #'
 #' @section Supported file types:
-#' `data_read()` is a wrapper around the **haven**, **data.table**, **readr**
+#' - `data_read()` is a wrapper around the **haven**, **data.table**, **readr**
 #'  **readxl** and **rio** packages. Currently supported file types are `.txt`,
 #'  `.csv`, `.xls`, `.xlsx`, `.sav`, `.por`, `.dta` and `.sas` (and related
 #'  files). All other file types are passed to `rio::import()`.
+#' - `data_write()` is a wrapper around **haven**, **readr** and **rio**
+#'  packages, and supports writing files into all formats supported by these
+#'  packages.
 #'
 #' @section Compressed files (zip) and URLs:
 #' `data_read()` can also read the above mentioned files from URLs or from
@@ -42,7 +49,18 @@
 #' `data_read()` detects the appropriate `read_*()` function based on the
 #' file-extension of the data file. Thus, in most cases it should be enough to
 #' only specify the `path` argument. However, if more control is needed, all
-#' arguments in `...` are passed down to the related `read_*()` function.
+#' arguments in `...` are passed down to the related `read_*()` function. The
+#' same applies to `data_write()`, i.e. based on the file extension provided in
+#' `path`, the appropriate `write_*()` function is used automatically.
+#'
+#' @section SPSS specific behaviour:
+#' `data_read()` does *not* import user-defined ("tagged") `NA` values from
+#' SPSS, i.e. argument `user_na` is always set to `FALSE` when importing SPSS
+#' data with the **haven** package. Use `convert_to_na()` to define missing
+#' values in the imported data, if necessary. Furthermore, `data_write()`
+#' compresses SPSS files by default. If this causes problems with (older) SPSS
+#' versions, use `compress = "none"`, for example
+#' `data_write(data, "myfile.sav", compress = "none")`.
 #'
 #' @section Differences to other packages that read foreign data formats:
 #' `data_read()` is most comparable to `rio::import()`. For data files from
@@ -64,12 +82,21 @@ data_read <- function(path,
                       verbose = TRUE,
                       ...) {
   # extract first valid file from zip-file
-  if (.file_ext(path) == "zip") {
+  if (identical(.file_ext(path), "zip")) {
     path <- .extract_zip(path)
   }
 
+  # check for valid file type
+  file_type <- .file_ext(path)
+  if (!is.character(file_type) || file_type == "") {
+    insight::format_error(
+      "Could not detect file type. The `path` argument has no file extension.",
+      "Please provide a file path including extension, like \"myfile.csv\" or \"c:/Users/Default/myfile.sav\"."
+    )
+  }
+
   # read data
-  out <- switch(.file_ext(path),
+  out <- switch(file_type,
     "txt" = ,
     "csv" = .read_text(path, encoding, verbose, ...),
     "xls" = ,
@@ -84,11 +111,14 @@ data_read <- function(path,
   # tell user about empty columns
   if (verbose) {
     empty_cols <- empty_columns(out)
-    insight::format_alert(
-      sprintf("Following %i variables are empty:", length(empty_cols)),
-      text_concatenate(names(empty_cols)),
-      "\nUse `remove_empty_columns()` to remove them from the data frame."
-    )
+    # only message if we actually have empty columns
+    if (length(empty_cols)) {
+      insight::format_alert(
+        sprintf("Following %i variables are empty:", length(empty_cols)),
+        text_concatenate(names(empty_cols)),
+        "\nUse `remove_empty_columns()` to remove them from the data frame."
+      )
+    }
   }
 
   out
@@ -100,13 +130,13 @@ data_read <- function(path,
 
 .file_ext <- function(x) {
   pos <- regexpr("\\.([[:alnum:]]+)$", x)
-  ifelse(pos > -1L, substring(x, pos + 1L), "")
+  ifelse(pos > -1L, tolower(substring(x, pos + 1L)), "")
 }
 
 
 .extract_zip <- function(path) {
   files <- utils::unzip(path, list = TRUE)
-  files_ext <- sapply(files$Name, .file_ext)
+  files_ext <- vapply(files$Name, .file_ext, FUN.VALUE = character(1L))
 
   supported_filetypes <- c("txt", "csv", "xls", "xlsx", "sav", "por", "dta")
   dest <- files$Name[which(files_ext %in% supported_filetypes)]
@@ -131,7 +161,8 @@ data_read <- function(path,
   # user may decide whether we automatically detect variable type or not
   if (isTRUE(convert_factors)) {
     if (verbose) {
-      message("Preparing data... Almost there!")
+      msg <- "Variables where all values have associated labels are now converted into factors. If this is not intended, use `convert_factors = FALSE`."
+      insight::format_alert(msg)
     }
     x[] <- lapply(x, function(i) {
       # only proceed if not all missing
@@ -147,8 +178,13 @@ data_read <- function(path,
         if (!is.character(i)) {
           # if all values are labelled, we assume factor. Use labels as levels
           if (!is.null(value_labels) && length(value_labels) == insight::n_unique(i)) {
-            i <- factor(as.character(i), labels = names(value_labels))
+            if (is.numeric(i)) {
+              i <- factor(i, labels = names(value_labels))
+            } else {
+              i <- factor(as.character(i), labels = names(value_labels))
+            }
             value_labels <- NULL
+            attr(i, "converted_to_factor") <- TRUE
           } else {
             # else, fall back to numeric
             i <- as.numeric(i)
@@ -159,7 +195,8 @@ data_read <- function(path,
         }
 
         # drop unused value labels
-        if (!is.null(value_labels) && length(value_labels <- value_labels[value_labels %in% unique(i)])) {
+        value_labels <- value_labels[value_labels %in% unique(i)]
+        if (length(value_labels) > 0L) {
           attr(i, "labels") <- value_labels
         }
 
@@ -168,6 +205,19 @@ data_read <- function(path,
       }
       i
     })
+    # tell user how many variables were converted
+    if (verbose) {
+      cnt <- sum(vapply(x, function(i) isTRUE(attributes(i)$converted_to_factor), TRUE))
+      msg <- sprintf("%i out of %i variables were fully labelled and converted into factors.", cnt, ncol(x))
+      insight::format_alert(msg)
+    }
+  } else {
+    # drop haven class attributes
+    x[] <- lapply(x, function(i) {
+      # save labels
+      class(i) <- setdiff(class(i), c("haven_labelled", "vctrs_vctr"))
+      i
+    })
   }
 
   class(x) <- "data.frame"
@@ -181,7 +231,7 @@ data_read <- function(path,
 .read_spss <- function(path, encoding, convert_factors, verbose, ...) {
   insight::check_if_installed("haven", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- haven::read_sav(file = path, encoding = encoding, user_na = FALSE, ...)
   .post_process_imported_data(out, convert_factors, verbose)
@@ -191,7 +241,7 @@ data_read <- function(path,
 .read_stata <- function(path, encoding, convert_factors, verbose, ...) {
   insight::check_if_installed("haven", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- haven::read_dta(file = path, encoding = encoding, ...)
   .post_process_imported_data(out, convert_factors, verbose)
@@ -201,7 +251,7 @@ data_read <- function(path,
 .read_sas <- function(path, path_catalog, encoding, convert_factors, verbose, ...) {
   insight::check_if_installed("haven", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- haven::read_sas(data_file = path, catalog_file = path_catalog, encoding = encoding, ...)
   .post_process_imported_data(out, convert_factors, verbose)
@@ -211,7 +261,7 @@ data_read <- function(path,
 .read_excel <- function(path, encoding, verbose, ...) {
   insight::check_if_installed("readxl", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- readxl::read_excel(path, ...)
   class(out) <- "data.frame"
@@ -228,7 +278,7 @@ data_read <- function(path,
 
   insight::check_if_installed("readr", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- readr::read_delim(path, ...)
   class(out) <- "data.frame"
@@ -239,7 +289,7 @@ data_read <- function(path,
 .read_unknown <- function(path, convert_factors, verbose, ...) {
   insight::check_if_installed("rio", reason = paste0("to read files of type '", .file_ext(path), "'"))
   if (verbose) {
-    message("Reading data...")
+    insight::format_alert("Reading data...")
   }
   out <- rio::import(file = path, ...)
   .post_process_imported_data(out, convert_factors, verbose)
