@@ -14,7 +14,7 @@ test_that("data_reorder works as expected", {
 # preserve attributes --------------------------
 
 test_that("data_reorder preserves attributes", {
-  skip_if_not_installed("parameters")
+  skip_if_not_or_load_if_installed("parameters")
 
   m <- lm(Sepal.Length ~ Species, data = iris)
   out <- parameters::parameters(m)
@@ -23,5 +23,6 @@ test_that("data_reorder preserves attributes", {
   out2 <- data_reorder(out, 4:6)
   a2 <- attributes(out2)
 
-  expect_equal(names(a1), names(a2))
+  # attributes may not be in the same order
+  expect_true(all(names(a1) %in% names(a2)) && length(a1) == length(a2))
 })
