@@ -4,20 +4,20 @@ test_that("convert data frame to numeric", {
 })
 
 test_that("convert character to numeric", {
-  expect_equal(to_numeric(c("xyz", "ab")), c(2, 1))
+  expect_identical(to_numeric(c("xyz", "ab")), c(2, 1))
 })
 
 test_that("convert character to numeric Date", {
-  expect_warning(expect_equal(to_numeric(as.Date("2022-01-01")), 18993))
+  expect_warning(expect_identical(to_numeric(as.Date("2022-01-01")), 18993))
 })
 
 test_that("convert character to numeric preserve levels", {
   x <- as.factor(mtcars$gear)
-  expect_equal(
+  expect_identical(
     to_numeric(x, dummy_factors = FALSE),
     c(2, 2, 2, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 1, 1, 1, 1, 1, 2, 3, 3, 3, 3, 3, 2)
   )
-  expect_equal(
+  expect_identical(
     to_numeric(x, dummy_factors = FALSE, preserve_levels = TRUE),
     c(4, 4, 4, 3, 3, 3, 3, 4, 4, 4, 4, 3, 3, 3, 3, 3, 3, 4, 4, 4, 3, 3, 3, 3, 3, 4, 5, 5, 5, 5, 5, 4)
   )
@@ -25,12 +25,13 @@ test_that("convert character to numeric preserve levels", {
 
 test_that("convert character to numeric lowest", {
   mtcars$vs <- as.factor(mtcars$vs)
-  model <- glm(vs ~ wt + mpg, data = mtcars, family = "binomial")
-  expect_equal(
+  d <<- mtcars
+  model <- glm(vs ~ wt + mpg, data = d, family = "binomial")
+  expect_identical(
     to_numeric(insight::get_response(model), dummy_factors = FALSE),
     c(1, 1, 2, 2, 1, 2, 1, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 1, 1, 1, 1, 2, 1, 2, 1, 1, 1, 2)
   )
-  expect_equal(
+  expect_identical(
     to_numeric(insight::get_response(model), dummy_factors = FALSE, lowest = 0),
     c(0, 0, 1, 1, 0, 1, 0, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1)
   )
@@ -43,20 +44,20 @@ test_that("convert factor to numeric", {
 
 
 test_that("convert factor to numeric", {
-  expect_equal(to_numeric(c("abc", "xyz")), c(1, 2))
-  expect_equal(to_numeric(c("123", "789")), c(123, 789))
-  expect_equal(to_numeric(c("1L", "2e-3")), c(1, 0.002))
-  expect_equal(to_numeric(c("1L", "2e-3", "ABC")), c(1, 2, 3))
+  expect_identical(to_numeric(c("abc", "xyz")), c(1, 2))
+  expect_identical(to_numeric(c("123", "789")), c(123, 789))
+  expect_identical(to_numeric(c("1L", "2e-3")), c(1, 0.002))
+  expect_identical(to_numeric(c("1L", "2e-3", "ABC")), c(1, 2, 3))
 })
 
 
 test_that("convert factor to numeric, dummy factors", {
-  expect_equal(
+  expect_identical(
     to_numeric(c("abc", "xyz"), dummy_factors = TRUE),
     data.frame(abc = c(1, 0), xyz = c(0, 1)),
     ignore_attr = TRUE
   )
-  expect_equal(
+  expect_identical(
     to_numeric(c("1L", "2e-3", "ABC"), dummy_factors = TRUE),
     data.frame(`1L` = c(1, 0, 0), `2e-3` = c(0, 1, 0), ABC = c(0, 0, 1)),
     ignore_attr = TRUE
@@ -66,12 +67,12 @@ test_that("convert factor to numeric, dummy factors", {
 
 test_that("convert factor to numeric, append", {
   data(efc)
-  expect_equal(
+  expect_identical(
     colnames(to_numeric(efc)),
     c("c12hour", "e16sex", "e42dep.1", "e42dep.2", "e42dep.3", "e42dep.4", "c172code", "neg_c_7"),
     ignore_attr = TRUE
   )
-  expect_equal(
+  expect_identical(
     colnames(to_numeric(efc, append = TRUE)),
     c(
       "c12hour", "e16sex", "e42dep", "c172code", "neg_c_7", "e42dep_n",
@@ -79,12 +80,12 @@ test_that("convert factor to numeric, append", {
     ),
     ignore_attr = TRUE
   )
-  expect_equal(
+  expect_identical(
     colnames(to_numeric(efc, append = TRUE, dummy_factors = FALSE)),
     c("c12hour", "e16sex", "e42dep", "c172code", "neg_c_7", "e42dep_n"),
     ignore_attr = TRUE
   )
-  expect_equal(
+  expect_identical(
     colnames(to_numeric(efc, append = FALSE, dummy_factors = FALSE)),
     c("c12hour", "e16sex", "e42dep", "c172code", "neg_c_7"),
     ignore_attr = TRUE
@@ -94,7 +95,7 @@ test_that("convert factor to numeric, append", {
 
 test_that("convert factor to numeric, all numeric", {
   data(mtcars)
-  expect_equal(to_numeric(mtcars), mtcars)
+  expect_identical(to_numeric(mtcars), mtcars)
 })
 
 
@@ -111,48 +112,48 @@ test_that("convert factor to numeric, dummy factors, with NA", {
   ))
 
   # same observations are missing
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x1, dummy_factors = TRUE))),
     which(is.na(x1))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x2, dummy_factors = TRUE))),
     which(is.na(x2))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x3, dummy_factors = TRUE))),
     which(is.na(x3))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x4, dummy_factors = TRUE))),
     which(is.na(x4))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x5, dummy_factors = TRUE))),
     which(is.na(x5))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x6, dummy_factors = TRUE))),
     which(is.na(x6))
   )
-  expect_equal(
+  expect_identical(
     which(!complete.cases(to_numeric(x7, dummy_factors = TRUE))),
     which(is.na(x7))
   )
 
   # output has same number of observation as input
-  expect_equal(nrow(to_numeric(x1, dummy_factors = TRUE)), length(x1))
-  expect_equal(nrow(to_numeric(x2, dummy_factors = TRUE)), length(x2))
-  expect_equal(nrow(to_numeric(x3, dummy_factors = TRUE)), length(x3))
-  expect_equal(nrow(to_numeric(x4, dummy_factors = TRUE)), length(x4))
-  expect_equal(nrow(to_numeric(x5, dummy_factors = TRUE)), length(x5))
-  expect_equal(nrow(to_numeric(x6, dummy_factors = TRUE)), length(x6))
-  expect_equal(nrow(to_numeric(x7, dummy_factors = TRUE)), length(x7))
+  expect_identical(nrow(to_numeric(x1, dummy_factors = TRUE)), length(x1))
+  expect_identical(nrow(to_numeric(x2, dummy_factors = TRUE)), length(x2))
+  expect_identical(nrow(to_numeric(x3, dummy_factors = TRUE)), length(x3))
+  expect_identical(nrow(to_numeric(x4, dummy_factors = TRUE)), length(x4))
+  expect_identical(nrow(to_numeric(x5, dummy_factors = TRUE)), length(x5))
+  expect_identical(nrow(to_numeric(x6, dummy_factors = TRUE)), length(x6))
+  expect_identical(nrow(to_numeric(x7, dummy_factors = TRUE)), length(x7))
 })
 
 # select helpers ------------------------------
 test_that("to_numeric regex", {
-  expect_equal(
+  expect_identical(
     to_numeric(mtcars, select = "pg", regex = TRUE),
     to_numeric(mtcars, select = "mpg")
   )
