@@ -11,6 +11,22 @@ test_that("normalize work as expected", {
     ignore_attr = TRUE
   )
 
+  expect_equal(
+    normalize(c(0, 1, 5, -5, -2), include_bounds = 0.01),
+    c(0.5, 0.598, 0.99, 0.01, 0.304),
+    ignore_attr = TRUE,
+    tolerance = 1e-4
+  )
+
+  expect_equal(
+    normalize(c(0, 1, 5, -5, -2), include_bounds = "a", verbose = FALSE),
+    c(0.5, 0.6, 1, 0, 0.3),
+    ignore_attr = TRUE,
+    tolerance = 1e-4
+  )
+
+  expect_warning(normalize(c(0, 1, 5, -5, -2), include_bounds = "a", verbose = TRUE))
+
   expect_snapshot(head(normalize(trees)))
 })
 
@@ -61,7 +77,7 @@ test_that("normalize: all Na or Inf", {
 
 
 test_that("normalize: only one value", {
-  foo <- c(1)
+  foo <- 1
   expect_warning(
     normalize(x = foo),
     regexp = "Variable `foo` contains only one unique value and will"
@@ -87,8 +103,8 @@ test_that("normalize: only two values", {
 })
 
 test_that("normalize: factor", {
-  expect_equal(
-    normalize(factor(c(1:3))),
+  expect_identical(
+    normalize(factor(1:3)),
     factor(1:3)
   )
 })
@@ -102,10 +118,9 @@ test_that("normalize: matrix", {
 })
 
 test_that("normalize: select", {
-  skip_if_not_installed("poorman")
-  library(poorman)
+  skip_if_not_or_load_if_installed("poorman")
 
-  expect_equal(
+  expect_identical(
     normalize(
       iris,
       select = starts_with("Petal\\.L")
@@ -116,10 +131,9 @@ test_that("normalize: select", {
 })
 
 test_that("normalize: exclude", {
-  skip_if_not_installed("poorman")
-  library(poorman)
+  skip_if_not_or_load_if_installed("poorman")
 
-  expect_equal(
+  expect_identical(
     normalize(
       iris,
       exclude = ends_with("ecies")
@@ -133,8 +147,7 @@ test_that("normalize: exclude", {
 # with grouped data -------------------------------------------
 
 test_that("normalize (grouped data)", {
-  skip_if_not_installed("poorman")
-  library(poorman)
+  skip_if_not_or_load_if_installed("poorman")
 
   datawizard <- iris %>%
     group_by(Species) %>%
@@ -148,12 +161,11 @@ test_that("normalize (grouped data)", {
     ungroup() %>%
     pull(Sepal.Width)
 
-  expect_equal(datawizard, manual)
+  expect_identical(datawizard, manual)
 })
 
 test_that("normalize, include bounds (grouped data)", {
-  skip_if_not_installed("poorman")
-  library(poorman)
+  skip_if_not_or_load_if_installed("poorman")
 
   datawizard <- iris %>%
     group_by(Species) %>%
@@ -167,13 +179,12 @@ test_that("normalize, include bounds (grouped data)", {
     ungroup() %>%
     pull(Sepal.Width)
 
-  expect_equal(datawizard, manual)
+  expect_identical(datawizard, manual)
 })
 
 
 test_that("normalize, factor (grouped data)", {
-  skip_if_not_installed("poorman")
-  library(poorman)
+  skip_if_not_or_load_if_installed("poorman")
 
   datawizard <- iris %>%
     group_by(Species) %>%
@@ -183,12 +194,12 @@ test_that("normalize, factor (grouped data)", {
 
   manual <- iris$Species
 
-  expect_equal(datawizard, manual)
+  expect_identical(datawizard, manual)
 })
 
 # select helpers ------------------------------
 test_that("normalize regex", {
-  expect_equal(
+  expect_identical(
     normalize(mtcars, select = "pg", regex = TRUE),
     normalize(mtcars, select = "mpg")
   )
